@@ -1,3 +1,5 @@
+import copy
+
 from threading import local
 from attrdict import AttrDict
 
@@ -5,6 +7,8 @@ from uuid import uuid4
 
 from contextlib import ContextDecorator
 
+from django.conf import settings as django_settings
+
 from security.config import settings
 
 
@@ -27,12 +31,17 @@ class SecurityLogger(ContextDecorator, local):
         if data:
             self.data.update(data)
         self.parent_with_id = self._get_parent_with_id()
-        self.extra_data = extra_data
-        if self.extra_data is None:
-            self.extra_data = self.parent.extra_data if self.parent else {}
+        self._extra_data = extra_data
+        if self._extra_data is None:
+            self._extra_data = self.parent.extra_data if self.parent else {}
 
         if self.store:
             SecurityLogger.loggers.append(self)
+
+            if 'reversion' in django_settings.INSTALLED_APPS:
+                from reversion.signals import post_revision_commit
+
+                post_revision_commit.connect(self._post_revision_commit, weak=False)
         self.backend_logs = AttrDict()
 
     def _get_parent_with_id(self):
@@ -54,15 +63,35 @@ class SecurityLogger(ContextDecorator, local):
     def add_related_objects(self, *related_objects):
         self.related_objects |= set(related_objects)
 
+    @property
+    def extra_data(self):
+        return copy.deepcopy(self._extra_data)
+
     def update_extra_data(self, data):
-        self.extra_data.update(data)
+        self._extra_data.update(data)
 
     def close(self):
         if not SecurityLogger.loggers or SecurityLogger.loggers[-1] != self:
             raise RuntimeError('Log already finished')
-        else:
-            SecurityLogger.loggers.pop()
+
+        SecurityLogger.loggers.pop()
+        if 'reversion' in django_settings.INSTALLED_APPS:
+            from reversion.signals import post_revision_commit
+
+            post_revision_commit.disconnect(self._post_revision_commit)
 
     @property
     def release(self):
         return settings.RELEASE
+
+    def _post_revision_commit(self, **kwargs):
+        """
+        Called as a post save of revision model of the reversion library.
+        If log context manager is active input logged request, command
+        log or celery task run log is joined with revision via related objects.
+        """
+        self.update_extra_data({
+            'reversion': {
+                'revision_id': kwargs['revision_id'] if 'revision_id' in kwargs else kwargs['revision'].id
+            }
+        })
